#ifndef __BDIIFC_H__
#define __BDIIFC_H__

/*************************************************************************
|  COPYRIGHT (c) 1997 BY ABATRON AG
|*************************************************************************
|
|  PROJECT NAME: BDI Interface Library
|  FILENAME    : bdiifc.h
|
|  COMPILER    : Visual C++ V5.0 / V1.5
|
|  TARGET OS   : WIN32 / WIN16
|  TARGET HW   : PC
|
|  PROGRAMMER  : Abatron / RD
|  CREATION    : 22.07.97
|
|*************************************************************************
|
|  DESCRIPTION :
|  DLL to access the BDI functions
|
|*************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

/*************************************************************************
|  DEFINES
|*************************************************************************/

/* if PASCAL is not defined, we assume WIN32 */
#ifndef PASCAL
#define PASCAL      __stdcall
#endif

/* if FAR is not defined, we assume WIN32 */
#ifndef FAR
#define FAR
#endif

/* uncomment the following lines if the data types are not already defined */
/*
typedef unsigned long       DWORD;
typedef unsigned char       BYTE;
typedef unsigned short      WORD;
*/

/*************************************************************************
    CPU Types
 *************************************************************************/

#define BDI_CT_FAMILY_MASK  0xFF00  /* CPU family mask */

#define BDI_CT_UNKNOWN      0xFFFF  /* unknown target CPU */

#define BDI_CT_CPU12        0x80C0  /* CPU12:             */
#define BDI_CT_HC812A4      0x03C0  /* CPU12: HC812A4     */
#define BDI_CT_HC912B32     0x03C1  /* CPU12: HC912B32    */
#define BDI_CT_HC912D60     0x03C3  /* CPU12: HC912D60    */
#define BDI_CT_HC912DG128   0x03C4  /* CPU12: HC912DG128  */
#define BDI_CT_HC912DA128   0x03C5  /* CPU12: HC912DA128  */
#define BDI_CT_HC912D60A    0x03C6  /* CPU12: HC912D60A   */
#define BDI_CT_HC912DG128A  0x03C7  /* CPU12: HC912DG128A */
#define BDI_CT_HC912DT128A  0x03C8  /* CPU12: HC912DT128A */
#define BDI_CT_MC9S12D256   0x03C9  /* CPU12: MC9S12Dx256 */
#define BDI_CT_MC9S12D128   0x03CA  /* CPU12: MC9S12Dx128 */
#define BDI_CT_MC9S12D64    0x03CB  /* CPU12: MC9S12Dx64  */
#define BDI_CT_MC9S12D32    0x03CC  /* CPU12: MC9S12Dx32  */
#define BDI_CT_MC9S12D512   0x03CD  /* CPU12: MC9S12Dx512 */
#define BDI_CT_MC9S12E256   0x03CE  /* CPU12: MC9S12E256  */
#define BDI_CT_MC9S12E128   0x03CF  /* CPU12: MC9S12E128  */

#define BDI_CT_S12X_128K1   0x03E0  /* CPU12: MC9S12X_128 */
#define BDI_CT_S12X_256K2   0x03E1  /* CPU12: MC9S12X_256 */
#define BDI_CT_S12X_512K4   0x03E2  /* CPU12: MC9S12X_512 */
#define BDI_CT_S12_256K2_2K 0x03E3  /* CPU12: S12 256K 2K  */
#define BDI_CT_S12XE        0x03E4  /* CPU12: S12XE        */

#define BDI_CT_CUSTOM_1     0x80C1  /* CPU12: Custom 1    */

#define BDI_CT_CPU16        0x8100  /* CPU16: */

#define BDI_CT_CPU32        0x8200  /* CPU32: */

#define BDI_CT_MCF          0x8300  /* ColdFire: */
#define BDI_CT_MCF5202      0x8301  /* ColdFire: MCF5202 */
#define BDI_CT_MCF5203      0x8302  /* ColdFire: MCF5203 */
#define BDI_CT_MCF5204      0x8303  /* ColdFire: MCF5204 */
#define BDI_CT_MCF5206      0x8304  /* ColdFire: MCF5206 */
#define BDI_CT_MCF5307      0x8305  /* ColdFire: MCF5307 */
#define BDI_CT_MCF5407      0x8306  /* ColdFire: MCF5407 */
#define BDI_CT_MCF5272      0x8307  /* ColdFire: MCF5272 */
#define BDI_CT_MCF5249      0x8308  /* ColdFire: MCF5249 */
#define BDI_CT_MCF5282      0x8309  /* ColdFire: MCF5282 */
#define BDI_CT_MCF5480      0x830A  /* ColdFire: MCF5480 family */
#define BDI_CT_MCF5213      0x830B  /* ColdFire: MCF5213 family */
#define BDI_CT_MCF5445      0x830C  /* ColdFire: MCF5445 family */

#define BDI_CT_MPC8XX       0x8400  /* PowerPC: MPC8xx */
#define BDI_CT_MPC860       0x8401  /* PowerPC: MPC860 */
#define BDI_CT_MPC821       0x8402  /* PowerPC: MPC821 */
#define BDI_CT_MPC823       0x8403  /* PowerPC: MPC823 */
#define BDI_CT_MPC850       0x8404  /* PowerPC: MPC850 */
#define BDI_CT_MPC801       0x8405  /* PowerPC: MPC801 */

#define BDI_CT_MPC5XX       0x8500  /* PowerPC: MPC5xx */
#define BDI_CT_MPC505       0x8501  /* PowerPC: MPC505 */
#define BDI_CT_MPC509       0x8502  /* PowerPC: MPC509 */
#define BDI_CT_MPC555       0x8503  /* PowerPC: MPC555 */

#define BDI_CT_MCORE        0x8600  /* M-CORE:    */
#define BDI_CT_MMC2001      0x8601  /* M-CORE: MMC2001 */
#define BDI_CT_MMC2107      0x8602  /* M-CORE: MMC2107 */
#define BDI_CT_MMC2114      0x8603  /* M-CORE: MMC2114 */

#define BDI_CT_ARM7TDMI     0x8700  /* ARM7: ARM7TDMI  */
#define BDI_CT_ARM7DI       0x8701  /* ARM7: ARM7DI    */
#define BDI_CT_ARM710T      0x8702  /* ARM7: ARM710T   */
#define BDI_CT_ARM720T      0x8703  /* ARM7: ARM720T   */
#define BDI_CT_ARM740T      0x8704  /* ARM7: ARM740T   */
#define BDI_CT_MAC7100      0x8705  /* ARM7: MAC7100   */

#define BDI_CT_ARM9TDMI     0x8800  /* ARM9: ARM9TDMI  */
#define BDI_CT_ARM920T      0x8801  /* ARM9: ARM920T   */
#define BDI_CT_ARM940T      0x8802  /* ARM9: ARM940T   */
#define BDI_CT_TI925T       0x8803  /* ARM9: TI925T    */

#define BDI_CT_ARM9E        0x8810  /* ARM9: ARM9E     */
#define BDI_CT_ARM946E      0x8811  /* ARM9: ARM946E   */
#define BDI_CT_ARM966E      0x8812  /* ARM9: ARM966E   */
#define BDI_CT_ARM926E      0x8813  /* ARM9: ARM926E   */
#define BDI_CT_FA526        0x8814  /* ARM9: Farady FA526   */
#define BDI_CT_FERO926      0x8815  /* ARM9: Marvell Feroceon 926 */
#define BDI_CT_FERO946      0x8816  /* ARM9: Marvell Feroceon 946 */
#define BDI_CT_FERO966      0x8817  /* ARM9: Marvell Feroceon 966 */

#define BDI_CT_ARM11        0x8820  /* ARM11: ARM11       */
#define BDI_CT_ARM1136      0x8821  /* ARM11: ARM1136     */
#define BDI_CT_ARM1156      0x8822  /* ARM11: ARM1156     */
#define BDI_CT_ARM1176      0x8823  /* ARM11: ARM1176     */
#define BDI_CT_MPCORE       0x8824  /* ARM11: MPCORE      */

#define BDI_CT_CORTEX_A8    0x8830  /* Cortex-A8:         */
#define BDI_CT_OMAP3430     0x8831  /* Cortex-A8: OMAP34xx/35xx */
#define BDI_CT_CORTEX_A9    0x8832  /* Cortex-A9:          */
#define BDI_CT_CORTEX_A5    0x8833  /* Cortex-A5:          */
#define BDI_CT_CORTEX_A7    0x8834  /* Cortex-A7:          */
#define BDI_CT_CORTEX_A15   0x8835  /* Cortex-A15:         */

#define BDI_CT_CORTEX_M3    0x8840  /* Cortex-Mx: M0/M3/M4 */

#define BDI_CT_XSCALE       0x8880  /* XSCALE: XSCALE     */

#define BDI_CT_TRICORE      0x8900  /* TriCore:           */

#define BDI_CT_PPC603E      0x8A00  /* PowerPC 603E       */
#define BDI_CT_PPC603EV     0x8A01  /* PowerPC: PPC603ev  */
#define BDI_CT_MPC8260      0x8A02  /* PowerPC: MPC8260   */
#define BDI_CT_MPC8240      0x8A03  /* PowerPC: MPC8240   */
#define BDI_CT_MPC4200      0x8A04  /* PowerPC: MPC4200   */
#define BDI_CT_MPC8280      0x8A05  /* PowerPC: MPC8280   */
#define BDI_CT_MGT5200      0x8A06  /* PowerPC: MGT5200   */
#define BDI_CT_MPC8220      0x8A07  /* PowerPC: MPC8220   */
#define BDI_CT_MPC8300      0x8A08  /* PowerPC: MPC8300   */

#define BDI_CT_PPC750       0x8B00  /* PowerPC PPC750/740 */

#define BDI_CT_PPC403       0x8C00  /* IBM PowerPC 403    */

#define BDI_CT_PPC405       0x8D00  /* IBM PowerPC 405    */

#define BDI_CT_PPC7400      0x8E00  /* PowerPC PPC7400    */
#define BDI_CT_PPC7450      0x8E10  /* PowerPC PPC745x/4x */
#define BDI_CT_PPC8600      0x8E20  /* PowerPC PPC86xx    */

#define BDI_CT_PPC401       0x8F00  /* IBM PowerPC 401    */

#define BDI_CT_PPC440       0x9000  /* IBM PowerPC 440    */
#define BDI_CT_PPC464       0x9001  /* IBM PowerPC 464    */
#define BDI_CT_PPC465       0x9002  /* IBM PowerPC 465    */
#define BDI_CT_PPC476       0x9003  /* IBM PowerPC 476    */
#define BDI_CT_HPC          0x9010  /* AMCC HPC core      */

#define BDI_CT_MIPS32       0x9100  /* MIPS32             */
#define BDI_CT_RC32300      0x9101  /* IDT RC32300        */
#define BDI_CT_AU1000       0x9102  /* Alchemy AU1000     */
#define BDI_CT_M4K          0x9103  /* MIPS32 4K          */
#define BDI_CT_M4KE         0x9104  /* MIPS32 4KE         */
#define BDI_CT_M24K         0x9105  /* MIPS32 24K         */
#define BDI_CT_BCM7401      0x9106  /* Broadcom BCM7401   */

#define BDI_CT_MPC8500      0x9200  /* PowerPC  MPC85xx   */
#define BDI_CT_MPC8560      0x9201  /* PowerPC: MPC8560   */
#define BDI_CT_MPC8540      0x9202  /* PowerPC: MPC8540   */
#define BDI_CT_MPC8548      0x9203  /* PowerPC: MPC8548   */
#define BDI_CT_MPC8572      0x9204  /* PowerPC: MPC8572   */
#define BDI_CT_MPC8536      0x9205  /* PowerPC: MPC8536   */
#define BDI_CT_MPC8569      0x9206  /* PowerPC: MPC8569   */
#define BDI_CT_P2020        0x9207  /* PowerPC: P2020     */
#define BDI_CT_P1020        0x9208  /* PowerPC: P1020     */
#define BDI_CT_P1010        0x9209  /* PowerPC: P1010     */

#define BDI_CT_MPC5500      0x9300  /* PowerPC  MPC55xx   */
#define BDI_CT_MPC5550      0x9301  /* PowerPC  MPC555x   */
#define BDI_CT_MPC5560      0x9302  /* PowerPC  MPC556x   */
#define BDI_CT_MPC5530      0x9303  /* PowerPC  MPC553x   */
#define BDI_CT_MPC5510      0x9304  /* PowerPC  MPC551x   */

#define BDI_CT_P4000        0x9400  /* PowerPC: P40xx     */
#define BDI_CT_P4080        0x9401  /* PowerPC: P4080     */
#define BDI_CT_P5020        0x9402  /* PowerPC: P5020     */
#define BDI_CT_T1000        0x9410  /* PowerPC: T1000     */
#define BDI_CT_T2000        0x9420  /* PowerPC: T2000     */
#define BDI_CT_T4000        0x9440  /* PowerPC: T4000     */


/*************************************************************************
    Init list commands
 *************************************************************************/

/* Init list commands for PPC targets */
#define BDI_INIT_PPC_NOP    0
#define BDI_INIT_PPC_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_PPC_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_PPC_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_PPC_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_PPC_WGPR   5   /* write to a GPR */
#define BDI_INIT_PPC_WSPR   6   /* write to a SPR */
#define BDI_INIT_PPC_WMSR   7   /* write to the MSR */
#define BDI_INIT_PPC_WCR    8   /* write to the CR */
#define BDI_INIT_PPC_SUPM   9   /* set the addresses of MCR MDR           */
#define BDI_INIT_PPC_WUPM   10  /* writes an entry into the UPM RAM array */

#define BDI_INIT_PPC_TSZ1   11  /* COP: maximal transfer size 1 byte */
#define BDI_INIT_PPC_TSZ2   12  /* COP: maximal transfer size 2 byte */
#define BDI_INIT_PPC_TSZ4   13  /* COP: maximal transfer size 4 byte */
#define BDI_INIT_PPC_TSZ8   14  /* COP: maximal transfer size 8 byte */
#define BDI_INIT_COP_MMAP   15  /* COP: define a valid memory range */
#define BDI_INIT_PPC_WM64   16  /* COP: write a 64 bit value to target memory */

#define BDI_INIT_PPC_WDCR   9   /* PPC400: device control register */
#define BDI_INIT_PPC_MMAP   10  /* PPC400: define a valid memory range */
#define BDI_INIT_PPC_WTLB   11  /* PPC440: add a TLB entry */
#define BDI_INIT_PPC_RM8    12  /* PPC400: read a  8bit value from target memory */
#define BDI_INIT_PPC_RM16   13  /* PPC400: read a 16bit value from target memory */
#define BDI_INIT_PPC_RM32   14  /* PPC400: read a 32bit value from target memory */
#define BDI_INIT_PPC_STLB   15  /* PPC440: setup Index, PID and flags in TLB Word 2 */
#define BDI_INIT_PPC_WIAR   16  /* PPC440: set instruction address register (PC) */

/* Init list commands for M-CORE targets */
#define BDI_INIT_MMC_NOP    0
#define BDI_INIT_MMC_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_MMC_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_MMC_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_MMC_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_MMC_WGPR   5   /* write to a GPR */
#define BDI_INIT_MMC_WAFR   6   /* write to a AFR */
#define BDI_INIT_MMC_WCR    7   /* write to the CR */
#define BDI_INIT_MMC_WPC    8   /* write to the PC */

/* Init list commands for ARM targets */
#define BDI_INIT_ARM_NOP    0
#define BDI_INIT_ARM_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_ARM_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_ARM_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_ARM_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_ARM_WGPR   5   /* write to a GPR */
#define BDI_INIT_ARM_WCPSR  6   /* write to the CPSR */
#define BDI_INIT_ARM_CP15   7   /* write to a CP15 register */
#define BDI_INIT_ARM_MMAP   8   /* define a valid memory range */
#define BDI_INIT_ARM_RM8    9   /* read a  8bit value from target memory */
#define BDI_INIT_ARM_RM16   10  /* read a 16bit value from target memory */
#define BDI_INIT_ARM_RM32   11  /* read a 32bit value from target memory */
#define BDI_INIT_ARM_EXEC   12  /* execute some helper code */

/* Init list commands for ARM11 targets */
#define BDI_INIT_ARM11_NOP    0
#define BDI_INIT_ARM11_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_ARM11_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_ARM11_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_ARM11_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_ARM11_WGPR   5   /* write to a GPR */
#define BDI_INIT_ARM11_WCPSR  6   /* write to the CPSR */
#define BDI_INIT_ARM11_CP15   7   /* write to a CP15 register */
#define BDI_INIT_ARM11_CP14   8   /* write to a CP14 register */
#define BDI_INIT_ARM11_CP13   9   /* write to a CP13 register */
#define BDI_INIT_ARM11_CP12   10  /* write to a CP12 register */
#define BDI_INIT_ARM11_CP11   11  /* write to a CP11 register */
#define BDI_INIT_ARM11_CP10   12  /* write to a CP10 register */
#define BDI_INIT_ARM11_CP9    13  /* write to a CP9  register */
#define BDI_INIT_ARM11_CP8    14  /* write to a CP8  register */
#define BDI_INIT_ARM11_CP7    15  /* write to a CP7  register */
#define BDI_INIT_ARM11_CP6    16  /* write to a CP6  register */
#define BDI_INIT_ARM11_CP5    17  /* write to a CP5  register */
#define BDI_INIT_ARM11_CP4    18  /* write to a CP4  register */
#define BDI_INIT_ARM11_CP3    19  /* write to a CP3  register */
#define BDI_INIT_ARM11_CP2    20  /* write to a CP2  register */
#define BDI_INIT_ARM11_CP1    21  /* write to a CP1  register */
#define BDI_INIT_ARM11_CP0    22  /* write to a CP0  register */
#define BDI_INIT_ARM11_WAPB   23  /* write to APB memory space */
#define BDI_INIT_ARM11_EXEC   24  /* execute code im memory */

/* Init list commands for XScale targets */
#define BDI_INIT_XSC_NOP    0
#define BDI_INIT_XSC_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_XSC_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_XSC_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_XSC_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_XSC_WGPR   5   /* write to a GPR */
#define BDI_INIT_XSC_WCPSR  6   /* write to the CPSR */
#define BDI_INIT_XSC_CP15   7   /* write to a CP15 register */
#define BDI_INIT_XSC_CP14   8   /* write to a CP14 register */
#define BDI_INIT_XSC_CP13   9   /* write to a CP13 register */
#define BDI_INIT_XSC_CP12   10  /* write to a CP12 register */
#define BDI_INIT_XSC_CP11   11  /* write to a CP11 register */
#define BDI_INIT_XSC_CP10   12  /* write to a CP10 register */
#define BDI_INIT_XSC_CP9    13  /* write to a CP9  register */
#define BDI_INIT_XSC_CP8    14  /* write to a CP8  register */
#define BDI_INIT_XSC_CP7    15  /* write to a CP7  register */
#define BDI_INIT_XSC_CP6    16  /* write to a CP6  register */
#define BDI_INIT_XSC_CP5    17  /* write to a CP5  register */
#define BDI_INIT_XSC_CP4    18  /* write to a CP4  register */
#define BDI_INIT_XSC_CP3    19  /* write to a CP3  register */
#define BDI_INIT_XSC_CP2    20  /* write to a CP2  register */
#define BDI_INIT_XSC_CP1    21  /* write to a CP1  register */
#define BDI_INIT_XSC_CP0    22  /* write to a CP0  register */

/* Init list commands for HC12 targets */
#define BDI_INIT_CPU12_NOP    0
#define BDI_INIT_CPU12_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_CPU12_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_CPU12_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_CPU12_WM32   4   /* write a 32bit value to target memory */

/* Init list commands for TriCore targets */
#define BDI_INIT_TRI_NOP    0
#define BDI_INIT_TRI_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_TRI_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_TRI_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_TRI_WM32   4   /* write a 32bit value to target memory */

/* Init list commands for MIPS32 targets */
#define BDI_INIT_MIPS_NOP   0
#define BDI_INIT_MIPS_DELAY 1   /* delay, value in milliseconds */
#define BDI_INIT_MIPS_WM8   2   /* write a  8bit value to target memory */
#define BDI_INIT_MIPS_WM16  3   /* write a 16bit value to target memory */
#define BDI_INIT_MIPS_WM32  4   /* write a 32bit value to target memory */
#define BDI_INIT_MIPS_WGPR  5   /* write to a GPR */
#define BDI_INIT_MIPS_WCP0  6   /* write to the CP0 registers */

/* Init list commands for ColdFire targets */
#define BDI_INIT_MCF_NOP    0
#define BDI_INIT_MCF_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_MCF_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_MCF_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_MCF_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_MCF_WDREG  5   /* write to a data register */
#define BDI_INIT_MCF_WAREG  6   /* write to a address registers */
#define BDI_INIT_MCF_WCREG  7   /* write to a control register */
#define BDI_INIT_MCF_MMAP   8   /* define a valid memory range */

/* Init list commands for MPC85xx targets */
#define BDI_INIT_PQ3_NOP    0
#define BDI_INIT_PQ3_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_PQ3_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_PQ3_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_PQ3_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_PQ3_WM64   5   /* write a 64 bit value to target memory */
#define BDI_INIT_PQ3_WGPR   6   /* write to a GPR */
#define BDI_INIT_PQ3_WSPR   7   /* write to a SPR */
#define BDI_INIT_PQ3_WMSR   8   /* write to the MSR */
#define BDI_INIT_PQ3_WCR    9   /* write to the CR */
#define BDI_INIT_PQ3_SUPM   10  /* set the addresses of MCR MDR           */
#define BDI_INIT_PQ3_WUPM   11  /* writes an entry into the UPM RAM array */
#define BDI_INIT_PQ3_TSZ1   12  /* maximal transfer size 1 byte */
#define BDI_INIT_PQ3_TSZ2   13  /* maximal transfer size 2 byte */
#define BDI_INIT_PQ3_TSZ4   14  /* maximal transfer size 4 byte */
#define BDI_INIT_PQ3_TSZ8   15  /* maximal transfer size 8 byte */
#define BDI_INIT_PQ3_MMAP   16  /* define a valid memory range */
#define BDI_INIT_PQ3_EXEC   17  /* execute some helper code */

/* Init list commands for MPC55xx targets */
#define BDI_INIT_P55_NOP    0
#define BDI_INIT_P55_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_P55_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_P55_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_P55_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_P55_FILL   5   /* fill a memory range with 64-bit writes */
#define BDI_INIT_P55_RM8    6   /* read a  8bit value from target memory */
#define BDI_INIT_P55_RM16   7   /* read a 16bit value from target memory */
#define BDI_INIT_P55_RM32   8   /* read a 32bit value from target memory */
#define BDI_INIT_P55_WGPR   9   /* write to a GPR */
#define BDI_INIT_P55_WSPR   10  /* write to a SPR */
#define BDI_INIT_P55_WMSR   11  /* write to the MSR */
#define BDI_INIT_P55_WCR    12  /* write to the CR */
#define BDI_INIT_P55_WPC    13  /* write to the PC */
#define BDI_INIT_P55_MMAP   14  /* define a valid memory range */
#define BDI_INIT_P55_WTLB   15  /* add a TLB entry */
#define BDI_INIT_P55_EXEC   16  /* execute some helper code */

/* Init list commands for QorIQ P4 targets */
#define BDI_INIT_QP4_NOP    0
#define BDI_INIT_QP4_DELAY  1   /* delay, value in milliseconds */
#define BDI_INIT_QP4_WM8    2   /* write a  8bit value to target memory */
#define BDI_INIT_QP4_WM16   3   /* write a 16bit value to target memory */
#define BDI_INIT_QP4_WM32   4   /* write a 32bit value to target memory */
#define BDI_INIT_QP4_WM64   5   /* write a 64 bit value to target memory */
#define BDI_INIT_QP4_WGPR   6   /* write to a GPR */
#define BDI_INIT_QP4_WSPR   7   /* write to a SPR */
#define BDI_INIT_QP4_WDCSR  8   /* write to a register in DCSR space */
#define BDI_INIT_QP4_WMSR   9   /* write to the MSR */
#define BDI_INIT_QP4_WCR    10  /* write to the CR */
#define BDI_INIT_QP4_WPC    11  /* write to the PC */
#define BDI_INIT_QP4_TSZ1   12  /* maximal transfer size 1 byte */
#define BDI_INIT_QP4_TSZ2   13  /* maximal transfer size 2 byte */
#define BDI_INIT_QP4_TSZ4   14  /* maximal transfer size 4 byte */
#define BDI_INIT_QP4_TSZ8   15  /* maximal transfer size 8 byte */
#define BDI_INIT_QP4_MMAP   16  /* define a valid memory range */
#define BDI_INIT_QP4_STLB   17  /* setup TLB (defines MAS1 and MAS2) */
#define BDI_INIT_QP4_WTLB   18  /* write TLB (defines MAS0/7 and MAS3) */


/*************************************************************************
    Register Types
 *************************************************************************/

/* Register types for PPC targets */
#define BDI_RT_PPC_GPR      100 /* General-purpose registers */
#define BDI_RT_PPC_FPR      101 /* Floating-point registers (currently not supported) */
#define BDI_RT_PPC_SPR      102 /* Special-purpose registers */
#define BDI_RT_PPC_CR       103 /* Condition Register */
#define BDI_RT_PPC_MSR      104 /* Machine State Register */
#define BDI_RT_PPC_FPSCR    105 /* Floating-point Status and Control Register */
#define BDI_RT_PPC_MM8      106 /* Memory mapped 8bit register */
#define BDI_RT_PPC_MM16     107 /* Memory mapped 16bit register */
#define BDI_RT_PPC_MM32     108 /* Memory mapped 32bit register */
#define BDI_RT_PPC_IAR      109 /* Instruction Address Register */
#define BDI_RT_PPC_SR       110 /* Segment Register */
#define BDI_RT_PPC_DCR      111 /* Device Control registers (PPC400) */
#define BDI_RT_PPC_PMR      112 /* Performance Monitor registers (MPC85xx) */

/* Register types for ColdFire targets */
#define BDI_RT_MCF_DATA     200 /* Data Registers */
#define BDI_RT_MCF_ADDR     201 /* Address Registers */
#define BDI_RT_MCF_CTRL     202 /* Control Registers */
#define BDI_RT_MCF_DBUG     203 /* Debug Module Registers */

/* Register addresses for ColdFire targets */
#define BDI_RA_MCF_CACR   0x002 /* Cache Control Register */
#define BDI_RA_MCF_ACR0   0x004 /* Access Control Unit 0 */
#define BDI_RA_MCF_ACR1   0x005 /* Access Control Unit 1 */
#define BDI_RA_MCF_VBR    0x801 /* Vector Base Register */
#define BDI_RA_MCF_SR     0x80E /* Status Register */
#define BDI_RA_MCF_PC     0x80F /* Program Counter */

#define BDI_RA_MCF_CSR    0x000 /* Debug: Configuration/Status */
#define BDI_RA_MCF_BAAR   0x005 /* Debug: BDM Address Attribute */
#define BDI_RA_MCF_AATR   0x006 /* Debug: Bus Address Attribute */
#define BDI_RA_MCF_TDR    0x007 /* Debug: Trigger Definition */
#define BDI_RA_MCF_PBR    0x008 /* Debug: PC Breakpoint */
#define BDI_RA_MCF_PBMR   0x009 /* Debug: PC Breakpoint Mask */
#define BDI_RA_MCF_ABHR   0x00C /* Debug: Operand Address High Breakpoint */
#define BDI_RA_MCF_ABLR   0x00D /* Debug: Operand Address Low Breakpoint */
#define BDI_RA_MCF_DBR    0x00E /* Debug: Data Breakpoint */
#define BDI_RA_MCF_DBMR   0x00F /* Debug: Data Breakpoint Mask */

/* Register types for CPU32 targets */
#define BDI_RT_CPU32_DATA   200 /* Data Registers */
#define BDI_RT_CPU32_ADDR   201 /* Address Registers */
#define BDI_RT_CPU32_PC     202 /* Program Counter */
#define BDI_RT_CPU32_SR     203 /* Status Register (32bit transfer) */
#define BDI_RT_CPU32_USP    204 /* User Stack Pointer */
#define BDI_RT_CPU32_SSP    205 /* Supervisor Stack Pointer */
#define BDI_RT_CPU32_VBR    206 /* Vector Base Register */
#define BDI_RT_CPU32_SFC    207 /* Source Function Code Register */
#define BDI_RT_CPU32_DFC    208 /* Destination Function Code Register */

/* Register types for CPU16 targets */
#define BDI_RT_CPU16_D      300 /* Register D */
#define BDI_RT_CPU16_E      301 /* Register E */
#define BDI_RT_CPU16_IX     302 /* Index Register X */
#define BDI_RT_CPU16_IY     303 /* Index Register Y */
#define BDI_RT_CPU16_IZ     304 /* Index Register Z */
#define BDI_RT_CPU16_K_EXT  305 /* Address Exzension (K) Register */
#define BDI_RT_CPU16_CCR    306 /* Condition Code Register [15:4] */
#define BDI_RT_CPU16_SP     307 /* Stack Pointer (includes extension SK) */
#define BDI_RT_CPU16_PC     308 /* Program Counter  (includes extension PK) */

#define BDI_RT_MAC_HR       310 /* MAC Register H */
#define BDI_RT_MAC_IR       311 /* MAC Register I */
#define BDI_RT_MAC_AM       312 /* MAC Register AM [31:0] */
#define BDI_RT_MAC_SL_AM    313 /* MAC Register SL and AM[35:32] */
#define BDI_RT_MAC_XM_YM    314 /* MAC Register XM:YM */

/* Register types for CPU12 targets */
#define BDI_RT_CPU12_D      400 /* Register D */
#define BDI_RT_CPU12_IX     401 /* Index Register X */
#define BDI_RT_CPU12_IY     402 /* Index Register Y */
#define BDI_RT_CPU12_SP     403 /* Stack Pointer */
#define BDI_RT_CPU12_PC     404 /* Program Counter */
#define BDI_RT_CPU12_CCR    405 /* Condition Code Register */
#define BDI_RT_CPU12_RPOS   406 /* Address of internal register space */
#define BDI_RT_CPU12_REG    407 /* Access a byte in the register space */
#define BDI_RT_CPU12_BDMB   408 /* Access a byte in BDM address space */
#define BDI_RT_CPU12_BDMW   409 /* Access a word in BDM address space */

/* Register types for M-CORE targets */
#define BDI_RT_MCORE_GPR    500 /* General-purpose registers */
#define BDI_RT_MCORE_AFR    501 /* Alternate register file */
#define BDI_RT_MCORE_PC     502 /* Program Counter */
#define BDI_RT_MCORE_PSR    503 /* Program Status Register */
#define BDI_RT_MCORE_CR     504 /* Control Registers */
#define BDI_RT_MCORE_ONCE   505 /* OnCE Registers */

/* Register addresses for M-CORE targets */
#define BDI_RA_MCORE_VBR    1
#define BDI_RA_MCORE_EPSR   2
#define BDI_RA_MCORE_FPSR   3
#define BDI_RA_MCORE_EPC    4
#define BDI_RA_MCORE_FPC    5
#define BDI_RA_MCORE_SS0    6
#define BDI_RA_MCORE_SS1    7
#define BDI_RA_MCORE_SS2    8
#define BDI_RA_MCORE_SS3    9
#define BDI_RA_MCORE_SS4    10
#define BDI_RA_MCORE_GCR    11
#define BDI_RA_MCORE_GSR    12

/* Register types for ARM targets */
#define BDI_RT_ARM_GPR      600 /* General-purpose registers */
#define BDI_RT_ARM_CPSR     601 /* Current process status register */
#define BDI_RT_ARM_ICEB     602 /* ICEBreaker registers */
#define BDI_RT_ARM_USR      603 /* user registers */
#define BDI_RT_ARM_FIQ      604 /* FIQ banked registers */
#define BDI_RT_ARM_SPSR_FIQ 605 /* FIQ saved process status register */
#define BDI_RT_ARM_SVC      606 /* supervisor banked registers */
#define BDI_RT_ARM_SPSR_SVC 607 /* supervisor saved process status register */
#define BDI_RT_ARM_ABT      608 /* abort banked registers */
#define BDI_RT_ARM_SPSR_ABT 609 /* abort saved process status register */
#define BDI_RT_ARM_IRQ      610 /* IRQ banked registers */
#define BDI_RT_ARM_SPSR_IRQ 611 /* IRQ saved process status register */
#define BDI_RT_ARM_UND      612 /* undefined banked registers */
#define BDI_RT_ARM_SPSR_UND 613 /* undefined saved process status register */

#define BDI_RT_ARM_CP15     614 /* CP15 registers */
#define BDI_RT_ARM_CP14     615 /* CP14 registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP13     616 /* CP13 registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP12     618 /* CP12 registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP11     617 /* CP11 registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP10     619 /* CP10 registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP9      620 /* CP9  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP8      621 /* CP8  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP7      622 /* CP7  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP6      623 /* CP6  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP5      624 /* CP5  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP4      625 /* CP4  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP3      626 /* CP3  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP2      627 /* CP2  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP1      628 /* CP1  registers (only XScale and ARM11) */
#define BDI_RT_ARM_CP0      629 /* CP0  registers (only XScale and ARM11) */

/* Register types for TriCore targets */
#define BDI_RT_TRICORE_DGPR 700 /* Data Registers */
#define BDI_RT_TRICORE_AGPR 701 /* Address Registers */
#define BDI_RT_TRICORE_PC   702 /* Program Counter */
#define BDI_RT_TRICORE_PSW  703 /* Status Register PSW*/
#define BDI_RT_TRICORE_PCXI 704 /* Status Register PCXI */

/* Register types for MIPS32 targets */
#define BDI_RT_MIPS_GPR     800 /* General-purpose registers */
#define BDI_RT_MIPS_PC      801 /* Current Program Counter */
#define BDI_RT_MIPS_HI      802 /* HI registers */
#define BDI_RT_MIPS_LO      803 /* LO registers */
#define BDI_RT_MIPS_CP0     804 /* CP0 registers */
#define BDI_RT_MIPS_CP1     805 /* CP1 registers */
#define BDI_RT_MIPS_FPR     806 /* Floating-point registers */


/*************************************************************************
    Other defines
 *************************************************************************/

/* address types */
#define BDI_AT_DEFAULT      0   /* default address space */
#define BDI_AT_GLOBAL       1   /* S12X: global address space */
#define BDI_AT_PHYSICAL     2   /* HC12: physical address space */

/* watch mode bits */
#define BDI_WATCH_EXECUTE   (1<<0)
#define BDI_WATCH_READ      (1<<1)
#define BDI_WATCH_WRITE     (1<<2)
#define BDI_WATCH_DATA      (1<<3)
#define BDI_WATCH_COMP      (1<<4)

#define BDI_WATCH_SIZE      (1<<6)
#define BDI_WATCH_MASK      (1<<7)

/* other defines */
#define BDI_BREAK_ALL       -1  /* used to select all breakpoints */
#define BDI_WATCH_ALL       -1  /* used to select all watchpoints */
#define BDI_MAX_ID_SIZE     40  /* maximal size of setup ID       */

/* Flash Types */
#define BDI_FLASH_AM29F0X0    2   /* e.g. Am29F010, Am29F040                */
#define BDI_FLASH_AM29F       2
#define BDI_FLASH_I28FBXB     5   /* e.g. i28F001BX, i28F400BX (byte-mode)  */
#define BDI_FLASH_I28BX8      5
#define BDI_FLASH_I28FBXW     6   /* e.g. i28F400BX (word-mode)             */
#define BDI_FLASH_I28BX16     6
#define BDI_FLASH_AM29FX00B   11  /* e.g. Am29F100 (byte-mode)              */
#define BDI_FLASH_AM29BX8     11
#define BDI_FLASH_AM29FX00W   12  /* e.g. Am29F100 (word-mode)              */
#define BDI_FLASH_AM29BX16    12
#define BDI_HC12_EEPROM       14  /* HC12 internal EEPROM                   */
#define BDI_HC12_FLASH        15  /* HC12 internal Flash                    */
#define BDI_MPC555_FLASH      16  /* MPC555 flash array                     */
#define BDI_CMFR_FLASH        16  /* MPC555/MMC2107 flash array             */
#define BDI_MPC555_SHADOW     17  /* MPC555 flash shadow info               */
#define BDI_CMFR_SHADOW       17  /* MPC555/MMC2107 flash shadow info       */
#define BDI_HC12A_EEPROM      18  /* internal EEPROM of HC12A targets       */
#define BDI_HC12A_FLASH       19  /* internal Flash of HC12A targets        */
#define BDI_STAR12_EEPROM     20  /* internal EEPROM of STAR12 targets      */
#define BDI_STAR12_FLASH      21  /* internal Flash of STAR2 targets        */
#define BDI_MCORE_SGFM        21  /* internal Flash of MMC2114,MMC2113      */
#define BDI_FLASH_AT49        22  /* Atmel AT49 byte mode only chip         */
#define BDI_FLASH_AT49X8      23  /* Atmel AT49 byte/word chip in byte mode */
#define BDI_FLASH_AT49X16     24  /* Atmel AT49 byte/word chip in word mode */
#define BDI_UC3F_FLASH        25  /* UC3F flash array                       */
#define BDI_UC3F_SHADOW       26  /* UC3F shadow information                */
#define BDI_FLASH_STRATAX8    29  /* Intel StrataFlash x8  mode             */
#define BDI_FLASH_STRATAX16   30  /* Intel StrataFlash x16 mode             */
#define BDI_FLASH_MIRROR      31  /* AMD MirrorBit Flash byte mode only chip         */
#define BDI_FLASH_MIRRORX8    32  /* AMD MirrorBit Flash byte/word chip in byte mode */
#define BDI_FLASH_MIRRORX16   33  /* AMD MirrorBit Flash byte/word chip in word mode */
#define BDI_FLASH_I28FBXD     34  /* Intel algorithm for x32 chip           */
#define BDI_FLASH_AM29DX16    35  /* AMD x32 chip  in x16 mode              */
#define BDI_FLASH_AM29DX32    36  /* AMD x32 chip  in x32 mode              */
#define BDI_FLASH_AM29BDDX16  37  /* Am29BDD160G chip in x16 mode           */
#define BDI_FLASH_AM29BDDX32  38  /* Am29BDD160G chip in x32 mode           */
#define BDI_FLASH_CFM         39  /* ColdFire Flash Module (MCF5282)        */
#define BDI_FLASH_CFM32       40  /* MAC7100 Code Flash Module              */
#define BDI_FLASH_CFM16       41  /* MAC7100 Data Flash Module              */
#define BDI_FLASH_LPC2000     42  /* Philips LPC2000 Flash Module           */
#define BDI_FLASH_LPC1000     42  /* Philips LPC1000 Flash Module           */
#define BDI_FLASH_STA2051     43  /* ST STA2051 internal flash              */
#define BDI_FLASH_STR710      43  /* ST STR71x internal flash               */
#define BDI_FLASH_ADUC7000    44  /* Analog Device ADuC7000 internal flash  */
#define BDI_FLASH_ST30F       45  /* ST ST30F internal flash                */
#define BDI_FLASH_AT91SAM7S   46  /* Atmel AT91SAM7Sxx internal flash       */
#define BDI_FLASH_S29M64X8    47  /* Spansion MirrorBit Flash 64 byte write buffer */
#define BDI_FLASH_S29M32X16   48  /* Spansion MirrorBit Flash 32 word write buffer */
#define BDI_FLASH_STR910F     49  /* ST STR91xF internal flash */
#define BDI_FLASH_H7F         50  /* MPC55xx flash array */
#define BDI_S12XE_PFLASH      51  /* S12XE FTM P-Flash   */
#define BDI_S12XE_DFLASH      52  /* S12XE FTM D-Flash   */
#define BDI_FLASH_STM32F10    53  /* ST STM32F10xxx internal flash */
#define BDI_FLASH_LM3S        54  /* Luminary Micro Stellaris internal flash */
#define BDI_FLASH_S29WSRX16   55  /* Spansion S29WS-R */
#define BDI_FLASH_SAM9XE      56  /* Atmel AT91SAM9XE internal flash */
#define BDI_FLASH_SAM7L       57  /* Atmel AT91SAM7L  internal flash */
#define BDI_FLASH_STM32L15    58  /* ST STM32L15xxx internal flash */
#define BDI_FLASH_EFM32       59  /* Energy Micro EFM32 internal flash */
#define BDI_FLASH_FTFL        60  /* Freescale Kinetis FTFL flash */
#define BDI_FLASH_S29GLSX16   61  /* Spansion S29GL-S */
#define BDI_FLASH_STM32F2     62  /* ST STM32F2 internal flash */
#define BDI_FLASH_STM32F4     63  /* ST STM32F4 internal flash */
#define BDI_FLASH_S29VSRX16   64  /* Spansion S29VS-R */
#define BDI_FLASH_STM32W      65  /* ST STM32W internal flash */
#define BDI_FLASH_FTFE        66  /* Freescale Kinetis K70 FTFE flash */


/* Firmware type, used to select correct firmware */
#define BDI_FWT_CPU32         0   /* CPU32/CPU16 targets */
#define BDI_FWT_MPC           5   /* MPC8xx / MPC5xx targets */
#define BDI_FWT_MCF           6   /* ColdFire targets */
#define BDI_FWT_CPU12         7   /* CPU12 targets */
#define BDI_FWT_MCORE         8   /* M-CORE targets */
#define BDI_FWT_ARM          10   /* ARM7TDMI targets */
#define BDI_FWT_TRICORE      11   /* TriCore targets */
#define BDI_FWT_COP          17   /* PPC6xx/7xx/82xx/74xx targets */
#define BDI_FWT_PPC400       20   /* PPC4xx targets */
#define BDI_FWT_QP4          25   /* QorIQ P3/P4/P5 targets */
#define BDI_FWT_MPC7450      27   /* MPC7450 targets */
#define BDI_FWT_MIPS32       30   /* MIPS32 targets */
#define BDI_FWT_XSCALE       33   /* XScale targets */
#define BDI_FWT_MPC8500      37   /* MPC85xx targets */
#define BDI_FWT_ARM11        40   /* ARM11 targets */
#define BDI_FWT_MPC5500      43   /* MPC55xx targets */
#define BDI_FWT_ARMSWD       47   /* ARM SWD targets */

/* Firmware update mode */
#define BDI_UPDATE_AUTO       0   /* update firmware/logic only needed */
#define BDI_UPDATE_FIRMWARE   1   /* update firmware in any case */
#define BDI_UPDATE_LOGIC      2   /* update logic in any case */
#define BDI_UPDATE_ALL        3   /* update firmware and logic in any case */


/* Option ID's */
#define BDI_OPT_ARM_SCANINIT  1   /* define ARM JTAG scan init string */
#define BDI_OPT_ARM_SCANPOST  2   /* define ARM JTAG scan post string */
#define BDI_OPT_ARM_HIGHADDR  3   /* define high part of 64-bit address */
#define BDI_OPT_ARM_MEMACCESS 4   /* define memory access mode */

#define BDI_OPT_PPC_HIGHADDR  1   /* define high part of 64-bit address */
#define BDI_OPT_PPC_MEMACCESS 2   /* define memory access mode */


/* BDI type */
#define BDI_TYPE_BDIHS         0
#define BDI_TYPE_BDI1000       1
#define BDI_TYPE_BDI2000       2
#define BDI_TYPE_BDI3000       3
#define BDI_TYPE_UNKOWN        255


/*************************************************************************
|  TYPEDEFS
|*************************************************************************/

typedef struct {
  WORD    regType;
  WORD    regAddr;
} BDI_RegTypeT;

typedef struct {
  WORD    fwType;
  WORD    fwVersion;
  WORD    cpuType;
  DWORD   setupTimeStamp;
  char    setupId[BDI_MAX_ID_SIZE];
} BDI_InfoT;

typedef struct {
  DWORD   command;
  DWORD   address;
  DWORD   value;
} BDI_InitTypeT;


#define BDI_ABORT_REQUEST  0xaba001

typedef int PASCAL FAR BDI_ProgressCallbackT(DWORD);


/*************************************************************************
|  FUNCTIONS
|*************************************************************************/

/****************************************************************************
 ****************************************************************************
                Base debug functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_Connect(const char FAR *parameter);
int PASCAL FAR BDI_Disconnect(void);
int PASCAL FAR BDI_RegisterGet(      WORD              count,
                               const BDI_RegTypeT FAR *pRegList,
                                     DWORD FAR        *pValues);

int PASCAL FAR BDI_RegisterSet(      WORD              count,
                               const BDI_RegTypeT FAR *pRegList,
                               const DWORD        FAR *pValues);

int PASCAL FAR BDI_FPRegGet(WORD first, WORD last, BYTE FAR *data);
int PASCAL FAR BDI_FPRegSet(WORD first, WORD last, const BYTE FAR *data);

int PASCAL FAR BDI_VRegGet(WORD first, WORD last, BYTE FAR *data);
int PASCAL FAR BDI_VRegSet(WORD first, WORD last, const BYTE FAR *data);

int PASCAL FAR BDI_MemoryRead(DWORD     addr,
                              WORD      space,
                              WORD      count,
                              BYTE FAR *data);

int PASCAL FAR BDI_MemoryWrite(      DWORD     addr,
                                     WORD      space,
                                     WORD      count,
                               const BYTE FAR* data);

int PASCAL FAR BDI_TargetStart(void);
int PASCAL FAR BDI_TargetHalt(void);
int PASCAL FAR BDI_TargetReset(void);
int PASCAL FAR BDI_TargetReset2(WORD resetTime);

int PASCAL FAR BDI_TargetStep(DWORD  lowerBound,
                              DWORD  upperBound,
                              WORD   stepCount,
                              DWORD *pc);

int PASCAL FAR BDI_BreakAdd(DWORD addr, DWORD interval);
int PASCAL FAR BDI_BreakRead(int breakId, DWORD FAR *count);
int PASCAL FAR BDI_BreakDelete(int BreakId);

int PASCAL FAR BDI_WatchAdd(WORD mode, DWORD from, DWORD to, DWORD count, DWORD data);
int PASCAL FAR BDI_WatchDelete(int watchId);

int PASCAL FAR BDI_InfoGet(BDI_InfoT FAR *bdiInfo);
int PASCAL FAR BDI_TypeGet(WORD FAR *bdiType,
                           WORD FAR *fwType,
                           WORD FAR *fwVersion);

int PASCAL FAR BDI_StateGet(WORD  FAR *state,
                            int   FAR *error,
                            DWORD FAR *timeStamp,
                            WORD  FAR *count,
                            DWORD FAR *info);

int PASCAL FAR BDI_TerminalRead(char FAR *data);
int PASCAL FAR BDI_TerminalWrite(char ch);

int PASCAL FAR BDI_DirectCommand(const char FAR *pszCommand,
                                       WORD      nBufferSize,
                                       char FAR *pszAnswer);

const char FAR* PASCAL FAR BDI_ErrorTextGet(int error);

int PASCAL FAR BDI_ChannelRead(WORD channel, WORD count, BYTE FAR *data);
int PASCAL FAR BDI_ChannelWrite(WORD channel, WORD count, const BYTE FAR* data);

int PASCAL FAR BDI_CoreSelect(WORD core, DWORD option);


/****************************************************************************
 ****************************************************************************
                Additional BDI Access functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_InitListReset(void);
int PASCAL FAR BDI_InitListAdd(WORD command, DWORD address, DWORD value);

int PASCAL FAR BDI_TargetStartup(      WORD               resetTime,
                                       DWORD              cpuClock,
                                       WORD               initCount,
                                 const BDI_InitTypeT FAR *pInitList);

int PASCAL FAR BDI_SetBdmSpeed(DWORD cpuClock);
int PASCAL FAR BDI_SetOption(BYTE id, const char FAR* data);

int PASCAL FAR BDI_GetByte(DWORD addr, BYTE  FAR *value);
int PASCAL FAR BDI_GetWord(DWORD addr, WORD  FAR *value);
int PASCAL FAR BDI_GetLong(DWORD addr, DWORD FAR *value);

int PASCAL FAR BDI_SetByte(DWORD addr, BYTE  value);
int PASCAL FAR BDI_SetWord(DWORD addr, WORD  value);
int PASCAL FAR BDI_SetLong(DWORD addr, DWORD value);

int PASCAL FAR BDI_DumpBlock(DWORD      addr,
                             WORD       count,
                             BYTE  FAR *block);

int PASCAL FAR BDI_DumpFile(const char  FAR *fileName,
                                  DWORD      addr,
                                  DWORD      count);

int PASCAL FAR BDI_DumpBinary(const char  FAR *fileName,
                                    DWORD      addr,
                                    DWORD      count);

int PASCAL FAR BDI_LoadBlock(DWORD      addr,
                             WORD       count,
                             BYTE  FAR *block,
                             DWORD FAR *errorAddr);

int PASCAL FAR BDI_LoadFile(const char  FAR *fileName,
                                  DWORD FAR *errorAddr);

int PASCAL FAR BDI_LoadFile2(const char  FAR *fileName,
                                   DWORD      offset,
                                   DWORD FAR *errorAddr);

int PASCAL FAR BDI_LoadBinary(const char  FAR *fileName,
                                    DWORD      startAddr,
                                    DWORD FAR *errorAddr);

int PASCAL FAR BDI_VerifyBlock(DWORD      addr,
                               WORD       count,
                               BYTE  FAR *block,
                               DWORD FAR *errorAddr);

int PASCAL FAR BDI_VerifyFile(const char  FAR *fileName,
                                    DWORD FAR *errorAddr);

int PASCAL FAR BDI_VerifyFile2(const char  FAR *fileName,
                                     DWORD      offset,
                                     DWORD FAR *errorAddr);

int PASCAL FAR BDI_VerifyBinary(const char  FAR *fileName,
                                      DWORD      startAddr,
                                      DWORD FAR *errorAddr);

int PASCAL FAR BDI_FileSize(const char FAR *fileName);

void PASCAL FAR BDI_InstallCallback(BDI_ProgressCallbackT* cb);


/****************************************************************************
 ****************************************************************************
                Low level JTAG access
 ****************************************************************************
 ****************************************************************************/

#define JTAG_CMD_CLOSE          0
#define JTAG_CMD_OPEN           1
#define JTAG_CMD_SPEED          2
#define JTAG_CMD_PORT           3
#define JTAG_CMD_CLOCK          4
#define JTAG_CMD_SCAN           5
#define JTAG_CMD_IRSCAN         6
#define JTAG_CMD_DRSCAN         7

#define JTAG_PORT_MASK          3
#define JTAG_PORT_KEEP          0
#define JTAG_PORT_LOW           1
#define JTAG_PORT_HIGH          2
#define JTAG_PORT_OPENDRAIN     1
#define JTAG_PORT_PUSHPULL      2

#define JTAG_CLOCK_TDO          (1<<1)
#define JTAG_CLOCK_TMS          (1<<0)

#define JTAG_SCAN_LAST          (1<<2)
#define JTAG_SCAN_DATA          (1<<1)
#define JTAG_SCAN_TMS           (1<<0)

#define JTAG_MAX_SCAN           8192


int PASCAL FAR BDI_DoJtag(      BYTE      command,
                                BYTE      control,
                                WORD      count,
                          const BYTE FAR *pScanOut,
                                BYTE FAR *pScanIn);


/****************************************************************************
 ****************************************************************************
                Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

#define BDI_ERASE_SECTOR        0
#define BDI_ERASE_PAGE          0
#define BDI_ERASE_BLOCK         1
#define BDI_ERASE_CHIP          2

#define BDI_ERASE_LOW           0  /* select MPC55xx flash space */
#define BDI_ERASE_MID           1
#define BDI_ERASE_HIGH          2
#define BDI_ERASE_SHADOW        3

int PASCAL FAR BDI_FlashSetType(WORD  flashType,
                                DWORD flashSize,
                                WORD  pageSize,
                                WORD  memoryWidth,
                                DWORD workSpace);

int PASCAL FAR BDI_FlashEraseSector(DWORD sectorAddr);
int PASCAL FAR BDI_FlashErase(WORD mode, DWORD addr);

int PASCAL FAR BDI_FlashWriteBlock(DWORD      addr,
                                   WORD       count,
                                   BYTE  FAR *block,
                                   DWORD FAR *errorAddr);

int PASCAL FAR BDI_FlashWriteFile(const char  FAR *fileName,
                                        DWORD FAR *errorAddr);

int PASCAL FAR BDI_FlashWriteFile2(const char  FAR *fileName,
                                         DWORD      offset,
                                         DWORD FAR *errorAddr);

int PASCAL FAR BDI_FlashWriteBinary(const char  FAR *fileName,
                                          DWORD      startAddr,
                                          DWORD FAR *errorAddr);


/****************************************************************************
 ****************************************************************************
                HC12 Flash/EEPROM Programming Functions
 ****************************************************************************
 ****************************************************************************/

#define BDI_CPU_HC812A4       0
#define BDI_CPU_HC912B32      1
#define BDI_CPU_HC912D60      2
#define BDI_CPU_HC912DG128    3
#define BDI_CPU_HC912DA128    4
#define BDI_CPU_HC912D60A     5
#define BDI_CPU_HC912DG128A   6
#define BDI_CPU_HC912DT128A   7
#define BDI_CPU_MC9S12D256    8
#define BDI_CPU_MC9S12D128    9
#define BDI_CPU_MC9S12D64     10
#define BDI_CPU_MC9S12D32     11
#define BDI_CPU_CUSTOM_1      12
#define BDI_CPU_MC9S12D512    13
#define BDI_CPU_MC9S12E256    14
#define BDI_CPU_MC9S12E128    15

/* alternate defines */
#define BDI_CPU_S12_256K4_4K  8
#define BDI_CPU_S12_128K2_2K  9
#define BDI_CPU_S12_64K1_1K   10
#define BDI_CPU_S12_32K1_1K   11
#define BDI_CPU_S12_512K4_4K  13
#define BDI_CPU_S12_256K2_4K  14
#define BDI_CPU_S12_128K1_2K  15

#define BDI_CPU_S12X_128K1    16
#define BDI_CPU_S12X_256K2    17
#define BDI_CPU_S12X_512K4    18

#define BDI_CPU_S12_256K2_2K  19  /* 256k flash, 2k EPROM */

#define BDI_CPU_S12XE         20


#define BDI_HC12_PAGED        (1<<15) /* Paged addresses in S-record file */


int PASCAL FAR BDI_FlashSetupHC12(WORD  cpuType,
                                  WORD  flashType,
                                  WORD  memoryWidth,
                                  DWORD flashSize,
                                  DWORD workSpace);

int PASCAL FAR BDI_FlashEraseHC12(DWORD flashAddr, DWORD flashSize);

int PASCAL FAR BDI_EnableAutoProgHC12(const char FAR          *commPort,
                                            WORD               cpuType,
                                            WORD               bdmClock,
                                            WORD               regAddr,
                                            WORD               ramAddr,
                                            WORD               initCount,
                                      const BDI_InitTypeT FAR *pInitList,
                                            BOOL               flashErase,
                                            BOOL               flashVerify,
                                      const char FAR          *flashName,
                                            BOOL               eepErase,
                                            BOOL               eepVerify,
                                      const char FAR          *eepName);


int PASCAL FAR BDI_DisableAutoProgHC12(const char FAR *commPort);


/****************************************************************************
 ****************************************************************************
                MPC555 internal Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_FlashSetup555(WORD  flashType,
                                 DWORD cpuClock,
                                 DWORD workSpace);

int PASCAL FAR BDI_FlashErase555(DWORD flashBase,
                                 DWORD blockMask,
                                 BOOL  clearCensor,
                                 DWORD cpuClock,
                                 DWORD workSpace);

int PASCAL FAR BDI_FlashWrite555(const char  FAR *fileName,
                                       DWORD FAR *errorAddr);

/****************************************************************************
 ****************************************************************************
                MPC56x internal Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_FlashSetupUC3F(WORD flashType, DWORD workSpace);

int PASCAL FAR BDI_FlashEraseUC3F(DWORD flashBase,
                                  DWORD blockMask,
                                  BOOL  clearCensor,
                                  DWORD workSpace);

/****************************************************************************
 ****************************************************************************
                MMC2107 internal Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_FlashSetup2107(WORD  flashType,
                                  DWORD cpuClock,
                                  DWORD workSpace);

int PASCAL FAR BDI_FlashErase2107(DWORD flashBase,
                                  DWORD blockMask,
                                  DWORD cpuClock,
                                  DWORD workSpace);

int PASCAL FAR BDI_FlashWrite2107(const char  FAR *fileName,
                                        DWORD FAR *errorAddr);

/****************************************************************************
 ****************************************************************************
                MMC2114 internal Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_FlashSetupSGFM(DWORD cpuClock, DWORD workSpace);


/****************************************************************************
 ****************************************************************************
                LPC2000 internal Flash Programming Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_FlashSetupLPC2000(DWORD flashSize,
                                     DWORD sysClock,
                                     DWORD workSpace);


/****************************************************************************
 ****************************************************************************
                Firmware/Logic Update Functions
 ****************************************************************************
 ****************************************************************************/

int PASCAL FAR BDI_UpdateFirmwareLogic(const char FAR *szPort,
                                       const char FAR *szPath,
                                             WORD      targetType,
                                             WORD      updateMode);

int PASCAL FAR BDI_ConfigNetwork(const char FAR *szPort,
                                 const char FAR *szBdiIP,
                                 const char FAR *szSubnetMask,
                                 const char FAR *szDefaultGateway);

int PASCAL FAR BDI_GetConfiguration(const char FAR *szPort,
                                          char FAR *szBdiType,
                                          char FAR *szBdiTarget,
                                          char FAR *szBdiVersions,
                                          char FAR *szBdiMAC,
                                          char FAR *szBdiIP,
                                          char FAR *szSubnetMask,
                                          char FAR *szDefaultGateway);

#ifdef __cplusplus
}
#endif

#endif

